@@ -6,6 +6,8 @@ import unicodedata
 from os import listdir
 from os.path import isfile, join
 
+import wordninja
+
 try:
 
     import PyPDF2
@@ -265,3 +267,22 @@ def what_does_the_robot_say(filename):
     remove_broken_words = " ".join(w for w in nltk.wordpunct_tokenize(string_tokens) \
                                    if w.lower() in words or not w.isalpha())
     return remove_broken_words
+
+
+def clean_plain_text_for_training(stringV):
+    for i in stringV:
+        split = wordninja.split(i)
+        cleanedText.append(split)
+    # b = wordninja.split(stringV)
+
+    print(len(cleanedText))
+    out = []
+    words = set(nltk.corpus.words.words())
+
+    for i in cleanedText:
+        screened = " ".join(w for w in nltk.wordpunct_tokenize(str(i)) \
+                            if w.lower() in words or not w.isalpha())
+
+        out.append(screened)
+    cleanedText_S = (list(itertools.chain.from_iterable(cleanedText)))
+    return cleanedText_S
